local name, ns = ...
local debug = ns.debug

local Addon = _G[name]
local tq = LibStub("LibTalentQuery-1.0")

local L = LibStub("AceLocale-3.0"):GetLocale(name)

local MIN_TIME_UNTIL_RESCAN = 60
local lastscan = {}

local talentSpecs = {}
local function updatetalent(event, name, realm, unit, guid)
	lastscan[name] = GetTime()
	local name = name .. (realm or "")
    local specId = GetInspectSpecialization(unit)
    local id, specname, description, icon, background, role = GetSpecializationInfoByID(specId)
	talentSpecs[name] = specId
end
tq.RegisterCallback(Addon, "TalentQuery_Ready", updatetalent)
tq.RegisterCallback(Addon, "TalentQuery_Ready_Outsider", updatetalent)

local function query(unit)
	local name = UnitName(unit)
	if UnitIsUnit(unit, "player") then
		talentSpecs[name] = GetSpecializationInfo(GetSpecialization())
		return
	end
	if not name then return end
	if not CanInspect(unit) or UnitLevel(unit) < 10 then return end
	local curTime = GetTime()
	local last = lastscan[name]
	if last and (curTime - last) < MIN_TIME_UNTIL_RESCAN then
		-- debug("skip rescan. next update will be in: ", MIN_TIME_UNTIL_RESCAN - curTime + last)
		return
	end
	tq:Query(unit)
end

local function getNameForTalentQuery(unit)
	if not UnitIsPlayer(unit) then return end
	local name, realm = UnitName(unit)
	if not name then return end
	if not CanInspect(unit) then return end
	if UnitLevel(unit) < 10 then return end
	query(unit)
	if realm then
		name = name .. realm
	end
	return name, talentSpecs[name]
end

local function TalentSpec(unit)
	local name, specId = getNameForTalentQuery(unit)
	if name then
		if specId then
			return "+"
		end
		return L["Scanning Talents..."]
	end
end
Addon.ScriptEnv.TalentSpec = TalentSpec

local function TalentScanning(unit)
	local name, specId = getNameForTalentQuery(unit)
	if name and not specId then
		return L["Scanning Talents..."]
	end
	return " "
end
Addon.ScriptEnv.TalentScanning = TalentScanning


local function TalentSpecRole(unit)
	local name, specId = getNameForTalentQuery(unit)
	if not name then return end
	if not specId then return "..." end
	local _, _, _, _, _, role = GetSpecializationInfoByID(specId)
	return _G[role]
end
Addon.ScriptEnv.TalentSpecRole = TalentSpecRole

local function TalentSpecName(unit)
	local name, specId = getNameForTalentQuery(unit)
	if not name then return end
	if not specId then return "..." end
	local _, specname = GetSpecializationInfoByID(specId)
	return specname
end
Addon.ScriptEnv.TalentSpecName = TalentSpecName

local function TalentSpecIcon(unit)
	local name, specId = getNameForTalentQuery(unit)
	if not name then return end
	if not specId then return end
	local _, _, _, icon = GetSpecializationInfoByID(specId)
	return icon
end
Addon.ScriptEnv.TalentSpecIcon = TalentSpecIcon
